@@ -34,4 +34,23 @@ class dpd:
         d['user_cnt'] = x[self.col_user_cnt].count()
         return pd.Series(d, index=['fpd0p_amt', 'fpd7p_amt','fpd15p_amt','fpd30p_amt','fpd0p_user','fpd7p_user','fpd15p_user','fpd30p_user','user_cnt'])
 
+    def dpd_checking(self, x):
+        """
+        Calculate fpd amount level and user level statistics from df
+        expect to group by before applying the function
+        example: df.groupby(['user_type']).apply(dpd_basic)
+        """
+        d = {}
+        d['fpd0p_principal'] = x[self.col_fpd0p_amt].sum()
+        d['fpd7p_principal'] = x[self.col_fpd7p_amt].sum()
+        d['fpd15p_principal'] = x[self.col_fpd15p_amt].sum()
+        d['fpd30p_principal'] = x[self.col_fpd30p_amt].sum()
+        d['fpd0p_user_cnt'] = x[self.col_is_fpd0].sum()
+        d['fpd7p_user_cnt'] = x[self.col_is_fpd7].sum()
+        d['fpd15p_user_cnt'] = x[self.col_is_fpd15].sum()
+        d['fpd30p_user_cnt'] = x[self.col_is_fpd30].sum()
+        d['user_cnt'] = x[self.col_user_cnt].count()
+        d['user_principal'] = x[self.col_user_principal].sum()
+        return pd.Series(d, index=['fpd0p_principal', 'fpd7p_principal','fpd15p_principal','fpd30p_principal','fpd0p_user_cnt','fpd7p_user_cnt','fpd15p_user_cnt','fpd30p_user_cnt','user_cnt', 'user_principal'])
+
 
